==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/service/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ModifyService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "modifyService");
    private final static QName _GetServices_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "getServices");
    private final static QName _ModifyServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "modifyServiceResponse");
    private final static QName _AddServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "addServiceResponse");
    private final static QName _RemoveServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "removeServiceResponse");
    private final static QName _AddService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "addService");
    private final static QName _GetServicesResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "getServicesResponse");
    private final static QName _RemoveService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "removeService");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link AddService }
     * 
     */
    public AddService createAddService() {
        return new AddService();
    }

    /**
     * Create an instance of {@link RemoveServiceResponse }
     * 
     */
    public RemoveServiceResponse createRemoveServiceResponse() {
        return new RemoveServiceResponse();
    }

    /**
     * Create an instance of {@link AddServiceResponse }
     * 
     */
    public AddServiceResponse createAddServiceResponse() {
        return new AddServiceResponse();
    }

    /**
     * Create an instance of {@link RemoveService }
     * 
     */
    public RemoveService createRemoveService() {
        return new RemoveService();
    }

    /**
     * Create an instance of {@link GetServicesResponse }
     * 
     */
    public GetServicesResponse createGetServicesResponse() {
        return new GetServicesResponse();
    }

    /**
     * Create an instance of {@link ModifyService }
     * 
     */
    public ModifyService createModifyService() {
        return new ModifyService();
    }

    /**
     * Create an instance of {@link ModifyServiceResponse }
     * 
     */
    public ModifyServiceResponse createModifyServiceResponse() {
        return new ModifyServiceResponse();
    }

    /**
     * Create an instance of {@link GetServices }
     * 
     */
    public GetServices createGetServices() {
        return new GetServices();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ModifyService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "modifyService")
    public JAXBElement<ModifyService> createModifyService(ModifyService value) {
        return new JAXBElement<ModifyService>(_ModifyService_QNAME, ModifyService.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetServices }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "getServices")
    public JAXBElement<GetServices> createGetServices(GetServices value) {
        return new JAXBElement<GetServices>(_GetServices_QNAME, GetServices.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ModifyServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "modifyServiceResponse")
    public JAXBElement<ModifyServiceResponse> createModifyServiceResponse(ModifyServiceResponse value) {
        return new JAXBElement<ModifyServiceResponse>(_ModifyServiceResponse_QNAME, ModifyServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "addServiceResponse")
    public JAXBElement<AddServiceResponse> createAddServiceResponse(AddServiceResponse value) {
        return new JAXBElement<AddServiceResponse>(_AddServiceResponse_QNAME, AddServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RemoveServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "removeServiceResponse")
    public JAXBElement<RemoveServiceResponse> createRemoveServiceResponse(RemoveServiceResponse value) {
        return new JAXBElement<RemoveServiceResponse>(_RemoveServiceResponse_QNAME, RemoveServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "addService")
    public JAXBElement<AddService> createAddService(AddService value) {
        return new JAXBElement<AddService>(_AddService_QNAME, AddService.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetServicesResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "getServicesResponse")
    public JAXBElement<GetServicesResponse> createGetServicesResponse(GetServicesResponse value) {
        return new JAXBElement<GetServicesResponse>(_GetServicesResponse_QNAME, GetServicesResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RemoveService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "removeService")
    public JAXBElement<RemoveService> createRemoveService(RemoveService value) {
        return new JAXBElement<RemoveService>(_RemoveService_QNAME, RemoveService.class, null, value);
    }

}

==> tv_10.2510-2601090450.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/service/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ModifyService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "modifyService");
    private final static QName _GetServices_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "getServices");
    private final static QName _ModifyServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "modifyServiceResponse");
    private final static QName _AddServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "addServiceResponse");
    private final static QName _RemoveServiceResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "removeServiceResponse");
    private final static QName _AddService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "addService");
    private final static QName _GetServicesResponse_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "getServicesResponse");
    private final static QName _RemoveService_QNAME = new QName("http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", "removeService");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.service
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link AddService }
     * 
     */
    public AddService createAddService() {
        return new AddService();
    }

    /**
     * Create an instance of {@link RemoveServiceResponse }
     * 
     */
    public RemoveServiceResponse createRemoveServiceResponse() {
        return new RemoveServiceResponse();
    }

    /**
     * Create an instance of {@link AddServiceResponse }
     * 
     */
    public AddServiceResponse createAddServiceResponse() {
        return new AddServiceResponse();
    }

    /**
     * Create an instance of {@link RemoveService }
     * 
     */
    public RemoveService createRemoveService() {
        return new RemoveService();
    }

    /**
     * Create an instance of {@link GetServicesResponse }
     * 
     */
    public GetServicesResponse createGetServicesResponse() {
        return new GetServicesResponse();
    }

    /**
     * Create an instance of {@link ModifyService }
     * 
     */
    public ModifyService createModifyService() {
        return new ModifyService();
    }

    /**
     * Create an instance of {@link ModifyServiceResponse }
     * 
     */
    public ModifyServiceResponse createModifyServiceResponse() {
        return new ModifyServiceResponse();
    }

    /**
     * Create an instance of {@link GetServices }
     * 
     */
    public GetServices createGetServices() {
        return new GetServices();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ModifyService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "modifyService")
    public JAXBElement<ModifyService> createModifyService(ModifyService value) {
        return new JAXBElement<ModifyService>(_ModifyService_QNAME, ModifyService.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetServices }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "getServices")
    public JAXBElement<GetServices> createGetServices(GetServices value) {
        return new JAXBElement<GetServices>(_GetServices_QNAME, GetServices.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ModifyServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "modifyServiceResponse")
    public JAXBElement<ModifyServiceResponse> createModifyServiceResponse(ModifyServiceResponse value) {
        return new JAXBElement<ModifyServiceResponse>(_ModifyServiceResponse_QNAME, ModifyServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "addServiceResponse")
    public JAXBElement<AddServiceResponse> createAddServiceResponse(AddServiceResponse value) {
        return new JAXBElement<AddServiceResponse>(_AddServiceResponse_QNAME, AddServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RemoveServiceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "removeServiceResponse")
    public JAXBElement<RemoveServiceResponse> createRemoveServiceResponse(RemoveServiceResponse value) {
        return new JAXBElement<RemoveServiceResponse>(_RemoveServiceResponse_QNAME, RemoveServiceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "addService")
    public JAXBElement<AddService> createAddService(AddService value) {
        return new JAXBElement<AddService>(_AddService_QNAME, AddService.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetServicesResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "getServicesResponse")
    public JAXBElement<GetServicesResponse> createGetServicesResponse(GetServicesResponse value) {
        return new JAXBElement<GetServicesResponse>(_GetServicesResponse_QNAME, GetServicesResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RemoveService }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.internal.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "removeService")
    public JAXBElement<RemoveService> createRemoveService(RemoveService value) {
        return new JAXBElement<RemoveService>(_RemoveService_QNAME, RemoveService.class, null, value);
    }

}
